Struct webrtc_data::data_channel::PollDataChannel
source · [−]pub struct PollDataChannel { /* private fields */ }Expand description
A wrapper around around DataChannel, which implements AsyncRead and
AsyncWrite.
Both poll_read and poll_write calls allocate temporary buffers, which results in an
additional overhead.
Implementations
sourceimpl PollDataChannel
impl PollDataChannel
sourcepub fn new(data_channel: Arc<DataChannel>) -> Self
pub fn new(data_channel: Arc<DataChannel>) -> Self
Constructs a new PollDataChannel.
Examples
use webrtc_data::data_channel::{DataChannel, PollDataChannel, Config};
use sctp::stream::Stream;
use std::sync::Arc;
let dc = Arc::new(DataChannel::new(Arc::new(Stream::default()), Config::default()));
let poll_dc = PollDataChannel::new(dc);sourcepub fn into_inner(self) -> Arc<DataChannel>
pub fn into_inner(self) -> Arc<DataChannel>
Get back the inner data_channel.
sourcepub fn clone_inner(&self) -> Arc<DataChannel>
pub fn clone_inner(&self) -> Arc<DataChannel>
Obtain a clone of the inner data_channel.
sourcepub fn messages_sent(&self) -> usize
pub fn messages_sent(&self) -> usize
MessagesSent returns the number of messages sent
sourcepub fn messages_received(&self) -> usize
pub fn messages_received(&self) -> usize
MessagesReceived returns the number of messages received
sourcepub fn bytes_sent(&self) -> usize
pub fn bytes_sent(&self) -> usize
BytesSent returns the number of bytes sent
sourcepub fn bytes_received(&self) -> usize
pub fn bytes_received(&self) -> usize
BytesReceived returns the number of bytes received
sourcepub fn stream_identifier(&self) -> u16
pub fn stream_identifier(&self) -> u16
StreamIdentifier returns the Stream identifier associated to the stream.
sourcepub fn buffered_amount(&self) -> usize
pub fn buffered_amount(&self) -> usize
BufferedAmount returns the number of bytes of data currently queued to be sent over this stream.
sourcepub fn buffered_amount_low_threshold(&self) -> usize
pub fn buffered_amount_low_threshold(&self) -> usize
BufferedAmountLowThreshold returns the number of bytes of buffered outgoing data that is considered “low.” Defaults to 0.
sourcepub fn set_read_buf_capacity(&mut self, capacity: usize)
pub fn set_read_buf_capacity(&mut self, capacity: usize)
Set the capacity of the temporary read buffer (default: 8192).